/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.example.warehouse.manager.vo;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.bluestemsoftware.open.eoa.example.warehouse.manager.util.OutstandingRequest;

/**
 * Contains state related to fulfillment of a 'customer order' within context of warehouse
 * manager application.
 */
public class CustomerOrder {

    public static enum Status {
        PROMISED, SCHEDULED, SHIPPED
    }

    private String orderNumber;
    private String zipCode;
    private Double shipCost;
    private Date estShipDate;
    private Date actualShipDate;
    private Status status;
    private Set<Item> items;
    private Map<String, OutstandingRequest> outstandingRequests;

    /**
     * Constructs an order sans customer information, e.g. name and address, etc ... which is
     * elided to simplify example.
     * 
     * @param orderNumber
     * @param zipCode
     * @param items
     */
    public CustomerOrder(String orderNumber, String zipCode, Set<Item> items, double shipCost) {
        this.orderNumber = orderNumber;
        this.zipCode = zipCode;
        this.items = items;
        this.status = Status.PROMISED;
        this.shipCost = shipCost;
    }

    public Set<Item> getItems() {
        return items;
    }

    public String getOrderNumber() {
        return orderNumber;
    }

    public String getZipCode() {
        return zipCode;
    }

    public Status getStatus() {
        return status;
    }

    public void setStatus(Status status) {
        this.status = status;
    }

    public Double getShipCost() {
        return shipCost;
    }

    public Date getActualShipDate() {
        return actualShipDate;
    }

    public void setActualShipDate(Date actualShipDate) {
        this.actualShipDate = actualShipDate;
    }

    public Date getEstShipDate() {
        return estShipDate;
    }

    public void setEstShipDate(Date estShipDate) {
        this.estShipDate = estShipDate;
    }

    public void addOutstandingRequest(OutstandingRequest outstandingRequest) {
        if (outstandingRequests == null) {
            outstandingRequests = new HashMap<String, OutstandingRequest>();
        }
        outstandingRequests.put(outstandingRequest.getID(), outstandingRequest);
    }

    public OutstandingRequest getOutstandingRequest(String messageExchangeID) {
        if (outstandingRequests == null) {
            return null;
        }
        return outstandingRequests.get(messageExchangeID);
    }

}
